"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import { Summary } from "../types";
import { publishArticle, unpublishArticle } from "../action";

export default function PostSummary({
  metadata,
  loggedIn,
}: {
  metadata: Summary;
  loggedIn: boolean;
}) {
  const [elementColor, setElementColor] = useState("#999");
  const router = useRouter();

  const hoverStart = () => {
    setElementColor("#eee");
  };
  const hoverEnd = () => {
    setElementColor("#999");
  };
  const navigateToPost = () => {
    router.push(`/blog/post/${metadata.slug}`);
  };

  return (
    <div
      key={metadata.slug}
      style={{
        display: "flex",
        flexDirection: "column",
        borderColor: elementColor,
        transition: "border-color 0.3s linear",
        borderStyle: "solid",
        marginTop: "1rem",
      }}
    >
      <div
        style={{
          width: "100%",
          backgroundColor: elementColor,
          color: "#111",
          display: "flex",
          alignItems: "center",
          padding: "0.5rem",
          boxSizing: "border-box",
          fontSize: "1rem",
          cursor: "pointer",
          transition: "background-color 0.3s linear",
        }}
        onMouseEnter={hoverStart}
        onMouseLeave={hoverEnd}
        onClick={navigateToPost}
      >
        <span>{metadata.title}</span>
      </div>
      <div
        style={{
          display: "flex",
          flexDirection: "row",
          justifyContent: "space-between",
          fontSize: "0.9rem",
          maxWidth: "100%",
          flexWrap: "wrap",
        }}
      >
        <div
          style={{
            display: "flex",
            justifyContent: "flex-start",
            padding: "0.5rem",
            gap: 4,
          }}
        >
          tags: {metadata.tags.join(", ")}
        </div>
        <div
          style={{
            display: "flex",
            justifyContent: "flex-end",
            padding: "0.5rem",
            gap: 4,
          }}
        >
          {metadata.is_draft && (
            <>
              <span>draft - </span>
              <div
                style={{
                  cursor: "pointer",
                  color: "#999",
                  transition: "color 0.3s linear",
                }}
                onMouseOver={(e) => {
                  e.currentTarget.style.color = "#eee";
                }}
                onMouseLeave={(e) => {
                  e.currentTarget.style.color = "#999";
                }}
                onClick={async () => {
                  await publishArticle(metadata.slug);
                  router.refresh();
                }}
              >
                move to published
              </div>
            </>
          )}
          {!metadata.is_draft && (
            <>
              <div>
                <div>
                  <span>published: </span>
                  <span>{metadata.publishedDate.toLocaleDateString()}</span>
                </div>
                {loggedIn && (
                  <div
                    style={{
                      cursor: "pointer",
                      color: "#999",
                      transition: "color 0.3s linear",
                    }}
                    onMouseOver={(e) => {
                      e.currentTarget.style.color = "#eee";
                    }}
                    onMouseLeave={(e) => {
                      e.currentTarget.style.color = "#999";
                    }}
                    onClick={async () => {
                      await unpublishArticle(metadata.slug);
                      router.refresh();
                    }}
                  >
                    move to drafts
                  </div>
                )}
              </div>
            </>
          )}
        </div>
      </div>
      <div
        style={{
          width: "100%",
          height: "2px",
          backgroundColor: elementColor,
          transition: "background-color 0.3s linear",
        }}
      ></div>
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          padding: "1rem 0.5rem 0 0.5rem",
        }}
      >
        <div style={{ fontSize: "0.9rem" }}>
          {metadata.blurb}
          <span style={{ color: "#999" }}>&hellip;</span>
        </div>
      </div>
      <div
        style={{
          display: "flex",
          justifyContent: "flex-end",
          marginTop: "0.5rem",
        }}
      >
        <span
          style={{
            textDecoration: "none",
            color: "#222",
            transition: "background-color 0.3s linear",
            padding: "0.5rem 1rem",
            fontSize: "0.9rem",
            fontWeight: "500",
            display: "inline-flex",
            alignItems: "center",
            gap: "0.25rem",
            cursor: "pointer",
            backgroundColor: elementColor,
          }}
          onMouseEnter={hoverStart}
          onMouseLeave={hoverEnd}
          onClick={navigateToPost}
        >
          Read more <span style={{ fontSize: "1rem" }}>→</span>
        </span>
      </div>
    </div>
  );
}
