"use client";

import { useRouter } from "next/navigation";
import React from "react";

function Tag({ tag }: { tag: string }) {
  const router = useRouter();
  return (
    <span
      style={{
        fontWeight: "bold",
        cursor: "pointer",
        padding: "8px 6px",
        display: "inline-block",
        transition: "color 0.3s linear, font-size 0.3s ease",
      }}
      onMouseEnter={(e) => {
        e.currentTarget.style.color = "#fff";
      }}
      onMouseLeave={(e) => {
        e.currentTarget.style.color = "";
      }}
      onClick={() => router.push(`/blog/${tag}`)}
    >
      {tag}
    </span>
  );
}

function TagInfo({ tag }: { tag: string }) {
  const router = useRouter();
  return (
    <div
      style={{
        fontSize: 13,
        marginTop: "1rem",
        display: "flex",
        flexDirection: "column",
        gap: "0.5rem",
      }}
    >
      <span>showing posts tagged &quot;{tag}&quot;</span>
      <span
        style={{
          padding: "0.5rem 1rem",
          backgroundColor: "#333",
          width: "fit-content",
          transition: "background-color 0.3s linear",
          cursor: "pointer",
          userSelect: "none",
        }}
        onMouseOver={(e) => {
          e.currentTarget.style.backgroundColor = "#444";
        }}
        onMouseLeave={(e) => {
          e.currentTarget.style.backgroundColor = "#333";
        }}
        onClick={() => {
          router.push("/blog");
        }}
      >
        see all posts
      </span>
    </div>
  );
}

export default function TagOverview({
  currentTag,
  tags,
}: {
  currentTag: string | null;
  tags: string[];
}) {
  return (
    <>
      {!currentTag && (
        <div style={{ fontSize: 12, marginTop: "1rem" }}>
          tags:&nbsp;
          {tags.map((tag, i) => (
            <React.Fragment key={tag}>
              <Tag tag={tag} />
              {i < tags.length - 1 && (
                <span style={{ color: "#999" }}>&nbsp;|&nbsp;</span>
              )}
            </React.Fragment>
          ))}
        </div>
      )}
      {currentTag && <TagInfo tag={currentTag} />}
    </>
  );
}
