"use client";

import { useRouter } from "next/navigation";
import * as Types from "../../types";
import "highlight.js/styles/github-dark.css";
import { publishArticle, unpublishArticle } from "../../action";

export default function PostDisplay({
  post,
  loggedIn,
}: {
  post: Types.Post;
  loggedIn: boolean;
}) {
  const router = useRouter();
  return (
    <>
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          borderColor: "#999",
          transition: "border-color 0.3s linear",
          borderStyle: "solid",
          marginTop: "1rem",
        }}
      >
        <div
          style={{
            width: "100%",
            backgroundColor: "#999",
            color: "#111",
            display: "flex",
            alignItems: "center",
            padding: "0.5rem",
            boxSizing: "border-box",
            fontSize: "1rem",
          }}
        >
          <span>{post.title}</span>
        </div>
        <div
          style={{
            display: "flex",
            flexDirection: "row",
            justifyContent: "space-between",
            fontSize: "0.9rem",
            maxWidth: "100%",
            flexWrap: "wrap",
          }}
        >
          <div
            style={{
              display: "flex",
              justifyContent: "flex-start",
              padding: "0.5rem",
              gap: 4,
            }}
          >
            tags: {post.tags.join(", ")}
          </div>
          <div
            style={{
              display: "flex",
              justifyContent: "flex-end",
              padding: "0.5rem",
              gap: 4,
            }}
          >
            {post.is_draft && (
              <>
                <span>draft - </span>
                <div
                  style={{
                    cursor: "pointer",
                    color: "#999",
                    transition: "color 0.3s linear",
                  }}
                  onMouseOver={(e) => {
                    e.currentTarget.style.color = "#eee";
                  }}
                  onMouseLeave={(e) => {
                    e.currentTarget.style.color = "#999";
                  }}
                  onClick={async () => {
                    await publishArticle(post.slug);
                    router.refresh();
                  }}
                >
                  move to published
                </div>
              </>
            )}
            {!post.is_draft && (
              <>
                <div>
                  <div>
                    <span>published: </span>
                    <span>{post.publishedDate.toLocaleDateString()}</span>
                  </div>
                  {loggedIn && (
                    <div
                      style={{
                        cursor: "pointer",
                        color: "#999",
                        transition: "color 0.3s linear",
                      }}
                      onMouseOver={(e) => {
                        e.currentTarget.style.color = "#eee";
                      }}
                      onMouseLeave={(e) => {
                        e.currentTarget.style.color = "#999";
                      }}
                      onClick={async () => {
                        await unpublishArticle(post.slug);
                        router.refresh();
                      }}
                    >
                      move to drafts
                    </div>
                  )}
                </div>
              </>
            )}
          </div>
        </div>
        <div
          style={{
            width: "100%",
            height: "2px",
            backgroundColor: "#999",
          }}
        ></div>
        <div
          style={{
            display: "flex",
            flexDirection: "column",
            padding: "1rem 0.5rem 0 0.5rem",
          }}
        >
          <div style={{ fontSize: "0.9rem" }}>
            <div dangerouslySetInnerHTML={post.contentRendered} />
          </div>
        </div>
      </div>
      <div
        style={{
          display: "flex",
          justifyContent: "space-between",
          marginTop: "1rem",
        }}
      >
        {loggedIn ? (
          <div
            style={{
              backgroundColor: "#a66",
              color: "#111",
              fontSize: "0.8rem",
              padding: "0.5rem",
              transition: "background-color 0.3s linear",
              userSelect: "none",
              cursor: "pointer",
            }}
            onMouseOver={(e) => {
              e.currentTarget.style.backgroundColor = "#c88";
            }}
            onMouseOut={(e) => {
              e.currentTarget.style.backgroundColor = "#a66";
            }}
            onClick={() => router.push(`/blog/write/${post.slug}`)}
          >
            edit
          </div>
        ) : (
          <div></div>
        )}
        <span
          style={{
            backgroundColor: "#999",
            color: "#111",
            fontSize: "0.8rem",
            padding: "0.5rem",
            transition: "background-color 0.3s linear",
            userSelect: "none",
            cursor: "pointer",
          }}
          onMouseOver={(e) => {
            e.currentTarget.style.backgroundColor = "#eee";
          }}
          onMouseOut={(e) => {
            e.currentTarget.style.backgroundColor = "#999";
          }}
          onClick={() => router.push("/blog")}
        >
          return to all posts
        </span>
      </div>
    </>
  );
}
