"use client";

import { useState } from "react";
import ContentArea from "./ContentArea";
import { Post } from "../types";
import { savePostServer } from "./action";

export default function Write({ post }: { post?: Post }) {
  const [title, setTitle] = useState(post?.title ?? "");
  const [tagsString, setTagsString] = useState<string>(
    post?.tags.join(", ") ?? ""
  );
  const tags = tagsString.split(",").map((tag) => tag.trim());
  const [content, setContent] = useState(post?.contentMarkdown ?? "");

  const enabled =
    title.trim() !== "" && content.trim() !== "" && tags.length > 0;

  const savePost = async (is_draft: boolean) => {
    if (!enabled) return;
    await savePostServer(title, content, tags, is_draft, post?.slug);
  };

  return (
    <>
      <div style={{ marginBottom: "1rem" }}>write your post</div>
      <div
        style={{
          display: "flex",
          flexDirection: "column",
          gap: 8,
          fontSize: 14,
        }}
      >
        <span>title:</span>
        <input
          type="text"
          value={title}
          onChange={(e) => setTitle(e.target.value)}
          style={{
            borderStyle: "none",
            backgroundColor: "#333",
            color: "#eee",
            fontSize: 16,
            padding: 10,
          }}
        />
        <span>tags: (comma separated)</span>
        <input
          type="text"
          value={tagsString}
          onChange={(e) => setTagsString(e.target.value)}
          style={{
            borderStyle: "none",
            backgroundColor: "#333",
            color: "#eee",
            fontSize: 15,
          }}
        />
      </div>
      <ContentArea content={content} setContent={setContent} />
      <div
        style={{
          display: "flex",
          gap: 8,
          flexDirection: "row",
          justifyContent: "space-evenly",
          marginTop: "1rem",
        }}
      >
        <div
          style={{
            padding: "0.5rem 1rem",
            backgroundColor: enabled ? "#333" : "#222",
            userSelect: "none",
            cursor: enabled ? "pointer" : "default",
            transition: "background-color 0.3s linear",
          }}
          onMouseOver={(e) => {
            if (!enabled) return;
            e.currentTarget.style.backgroundColor = "#444";
          }}
          onMouseLeave={(e) => {
            if (!enabled) return;
            e.currentTarget.style.backgroundColor = "#333";
          }}
          onClick={() => savePost(true)}
        >
          save as draft
        </div>
        <div
          style={{
            padding: "0.5rem 1rem",
            backgroundColor: enabled ? "#353" : "#222",
            userSelect: "none",
            cursor: enabled ? "pointer" : "default",
            transition: "background-color 0.3s linear",
          }}
          onMouseOver={(e) => {
            if (!enabled) return;
            e.currentTarget.style.backgroundColor = "#464";
          }}
          onMouseLeave={(e) => {
            if (!enabled) return;
            e.currentTarget.style.backgroundColor = "#353";
          }}
          onClick={() => savePost(false)}
        >
          publish
        </div>
      </div>
    </>
  );
}
