import { notFound, redirect } from "next/navigation";
import { Post } from "../../types";
import Write from "../Write";
import { isLoggedIn } from "@/components/auth";
import { PrismaClient } from "@prisma/client";

export default async function WritePage({
  params,
}: {
  params: Promise<{ slug: string[] | undefined }>;
}) {
  if (!(await isLoggedIn())) {
    redirect("/blog/login");
  }

  const slug = (await params).slug?.[0];
  let post: Post | undefined = undefined;
  if (slug) {
    const prisma = new PrismaClient();
    const result =
      (await prisma.post.findUnique({
        where: { slug },
        include: { tags: true },
      })) ?? undefined;
    if (result == null) {
      notFound();
    }
    post = {
      ...result,
      tags: result.tags.map((tag) => tag.name),
      contentRendered: result.contentRendered as { __html: string },
    };
  }
  return <Write post={post} />;
}
