"use server";
import { redirect } from "next/navigation";
import { PrismaClient } from "@prisma/client";
import MarkdownIt from "markdown-it";
import hljs from "highlight.js";
import * as cheerio from "cheerio";
import slugify from "slugify";

export async function savePostServer(
  title: string,
  contentMarkdown: string,
  tags: string[],
  is_draft: boolean,
  existingSlug?: string
) {
  const prisma = new PrismaClient();

  const md = new MarkdownIt({
    linkify: true,
    typographer: true,
    highlight: (str, lang) => {
      if (lang && hljs.getLanguage(lang)) {
        try {
          return hljs.highlight(str, { language: lang }).value;
        } catch {}
      }
      return "";
    },
  });

  const contentRendered = { __html: md.render(contentMarkdown) };
  const blurb = cheerio.load(contentRendered.__html).text().substring(0, 200);
  const slug = slugify(title, { lower: true, strict: true });

  if (existingSlug) {
    await prisma.post.delete({ where: { slug: existingSlug } });
  }

  await prisma.post.create({
    data: {
      title,
      slug,
      publishedDate: new Date(),
      tags: {
        connectOrCreate: tags.map((tag) => ({
          where: { name: tag },
          create: { name: tag },
        })),
      },
      blurb,
      contentMarkdown,
      contentRendered,
      is_draft,
    },
  });

  redirect("/blog");
}
