"use client";

import { useState } from "react";
import React from "react";
import { navBarFont } from "./fonts";
import {
  PAGES,
  Pages,
  pathNameFromSelectedPage,
  selectedPageFromPathName,
} from "./pages";
import { usePathname, useRouter } from "next/navigation";

export default function Navbar() {
  const [hoveredPage, setHoveredPage] = useState<Pages | null>(null);

  const pathName = usePathname();
  const selectedPage = selectedPageFromPathName(pathName);
  const router = useRouter();

  const navbarItem = (page: Pages): React.CSSProperties => ({
    padding: "0.3rem 0.7rem",
    cursor: "pointer",
    backgroundColor:
      selectedPage == page || hoveredPage === page ? "#eee" : "transparent",
    color: selectedPage == page || hoveredPage == page ? "#222" : "#eee",
    transition: "all 0.3s ease",
  });

  return (
    <nav
      className={navBarFont.className}
      style={{
        fontWeight: "700",
        display: "flex",
        flexDirection: "row",
        gap: "1rem",
        fontSize: "1.1rem",
        flexWrap: "wrap",
        maxWidth: "90vw",
        justifyContent: "center",
      }}
    >
      {PAGES.map((page, index) => (
        <React.Fragment key={page}>
          <div
            style={navbarItem(page)}
            onClick={() => router.push(pathNameFromSelectedPage(page))}
            onMouseEnter={() => setHoveredPage(page)}
            onMouseLeave={() => setHoveredPage(null)}
          >
            <div style={{ userSelect: "none" }}>{page}</div>
          </div>
          {index < PAGES.length - 1 && <span>|</span>}
        </React.Fragment>
      ))}
    </nav>
  );
}
